]> git.decadent.org.uk Git - dak.git/blobdiff - katie.py
add s390 to arch list, autobuilding from accepted bits
[dak.git] / katie.py
index 871da565a9372e98c64699925ad1be759762e7a8..b2ac53a940b0e205d8da65346662a7683743f588 100644 (file)
--- a/katie.py
+++ b/katie.py
@@ -2,7 +2,7 @@
 
 # Utility functions for katie
 # Copyright (C) 2001  James Troup <james@nocrew.org>
-# $Id: katie.py,v 1.15 2002-04-21 15:38:29 troup Exp $
+# $Id: katie.py,v 1.17 2002-04-29 22:00:44 troup Exp $
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -288,6 +288,8 @@ class Katie:
 
             if action:
                 Subst["__ANNOUNCE_LIST_ADDRESS__"] = list;
+                if Cnf.get("Dinstall::TrackingServer") and changes["architecture"].has_key("source"):
+                    Subst["__ANNOUNCE_LIST_ADDRESS__"] = Subst["__ANNOUNCE_LIST_ADDRESS__"] + "\nBcc: %s@%s" % (changes["source"], Cnf["Dinstall::TrackingServer"])
                 mail_message = utils.TemplateSubst(Subst,open(Cnf["Dir::TemplatesDir"]+"/jennifer.announce","r").read());
                 utils.send_mail (mail_message, "")
 
@@ -357,24 +359,25 @@ class Katie:
             utils.send_mail(mail_message, "")
             self.announce(short_summary, 1)
 
-        ## FIXME: this should go away to some Debian specific file
-        # If we're accepting something for unstable do extra work to
-        # make it auto-buildable from accepted
-        if self.pkg.changes["distribution"].has_key("unstable"):
+        # Special support to enable clean auto-building of accepted packages
+        if Cnf.get("Dinstall::SpecialAcceptedAutoBuild") and \
+           self.pkg.changes["distribution"].has_key("unstable"):
             self.projectB.query("BEGIN WORK");
-            # Add it to the list of packages for later processing by apt-ftparchive
             for file in file_keys:
-                if files[file]["type"] == "dsc" or files[file]["type"] == "deb":
-                    filename = os.path.join(Cnf["Dir::QueueAcceptedDir"], file);
-                    self.projectB.query("INSERT INTO unstable_accepted (filename) VALUES ('%s')" % (filename));
-            # If the .orig.tar.gz is in the pool, create a symlink (if
-            # one doesn't already exist)
+                src = os.path.join(Cnf["Dir::QueueAcceptedDir"], file);
+                dest = os.path.join(Cnf["Dir::AcceptedAutoBuild"], file);
+                # Create a symlink to it
+                os.symlink(src, dest);
+                # Add it to the list of packages for later processing by apt-ftparchive
+                self.projectB.query("INSERT INTO unstable_accepted (filename, in_accepted) VALUES ('%s', 't')" % (dest));
+            # If the .orig.tar.gz is in the pool, create a symlink to
+            # it (if one doesn't already exist)
             if self.pkg.orig_tar_id:
                 # Determine the .orig.tar.gz file name
                 for dsc_file in self.pkg.dsc_files.keys():
                     if dsc_file[-12:] == ".orig.tar.gz":
                         filename = dsc_file;
-                dest = os.path.join(Cnf["Dir::QueueAcceptedDir"],filename);
+                dest = os.path.join(Cnf["Dir::AcceptedAutoBuild"],filename);
                 # If it doesn't exist, create a symlink
                 if not os.path.exists(dest):
                     # Find the .orig.tar.gz in the pool
@@ -384,6 +387,9 @@ class Katie:
                         utils.fubar("[INTERNAL ERROR] Couldn't find id %s in files table." % (self.pkg.orig_tar_id));
                     src = os.path.join(ql[0][0], ql[0][1]);
                     os.symlink(src, dest);
+                    # Add it to the list of packages for later processing by apt-ftparchive
+                    self.projectB.query("INSERT INTO unstable_accepted (filename, in_accepted) VALUES ('%s', 't')" % (dest));
+
             self.projectB.query("COMMIT WORK");
 
     ###########################################################################
@@ -459,7 +465,6 @@ class Katie:
             # safely overwrite it.
             utils.move(file, dest_file, 1, perms=0660);
 
-
     ###########################################################################
 
     def do_reject (self, manual = 0, reject_message = ""):